@@ -6,7 +6,7 @@ from pyage.core.stop_condition import StepLimitStopCondition
 from pyage_forams.solutions.environment import environment_factory, Environment3d
 from pyage_forams.solutions.foram import create_forams, create_agent
 from pyage_forams.solutions.genom import GenomFactory
-from pyage_forams.solutions.insolation_meter import InsolationMeter
+from pyage_forams.solutions.insolation_meter import StaticInsolation
 from pyage_forams.solutions.statistics import SimpleStatistics
 
 
@@ -14,9 +14,14 @@ factory = GenomFactory(chambers_limit=5)
 genom_factory = lambda: factory.generate
 forams = create_forams(8, initial_energy=5)
 agents = create_agent
-insolation_meter = InsolationMeter
+insolation_meter = StaticInsolation
 size = lambda: 10
 
+reproduction_minimum = lambda: 10
+movement_energy = lambda: 0.25
+growth_minimum = lambda: 10
+energy_need = lambda: 0.2
+
 environment = environment_factory(regeneration_factor=0.1, clazz=Environment3d)
 
 stop_condition = lambda: StepLimitStopCondition(90)
